# xlson

Python package for transforming Excel files to JSON files and manipulating them

## Installation

To install the package from PyPI type:

```
pip install xlson
```

Or from the repo:

```
pip install git+https://github.com/loven-doo/xlson.git
```

For 'dev' branch version:

```
pip install git+https://github.com/loven-doo/xlson.git@dev
```

## Package reference

### xlson.prepare_xl

### xlson.handlers.XLSonHandler


